@@ -3,4 +3,8 @@ import numpy as np
 def mape(y_true, y_pred):
     y_true = np.array(y_true)
     y_pred = np.array(y_pred)
-    return np.mean(np.abs((y_true - y_pred) / y_true)) * 100
\ No newline at end of file
+    return np.mean(np.abs((y_true - y_pred) / y_true)) * 100
+
+def mde_area(y, x):
+    area = np.trapz(y = y, x = x)
+    return area
\ No newline at end of file
