@@ -107,6 +107,8 @@ class tscausalinference:
         elif has_week:
             self.prio_simulations = weekly_season(bootstrap_samples = self.simulations, intervention = self.intervention, 
                                      predict_df = self.data)
+        else:
+            self.prio_simulations = self.simulations
         
         self.stadisticts, self.stats_ranges, self.samples_means = bootstrap_p_value(control = self.data.query(self.string_filter).yhat, 
                                                                                     treatment = self.data.query(self.string_filter).y, 
@@ -242,17 +244,21 @@ class sensitivity:
         self.regressors = regressors
         self.model_type = model_type
         self.autocorrelation = autocorrelation
+        self.verbose = verbose
+        self.n_samples = n_samples
 
-        self.data, self.analysis, self.hyper_parameters = sensitivity_analysis(df = df, 
-                         test_period = test_period, 
-                         cross_validation_steps = cross_validation_steps, 
-                         alpha = alpha, 
-                         model_params = model_params, 
-                         regressors= regressors,
-                         verbose = verbose,
-                         n_samples = n_samples,
-                         autocorrelation = autocorrelation,
-                         model_type = model_type)
+    def run(self):
+        self.data, self.analysis, self.hyper_parameters = sensitivity_analysis(df = self.df, 
+                         test_period = self.test_period, 
+                         cross_validation_steps = self.cross_validation_steps, 
+                         alpha = self.alpha, 
+                         model_params = self.model_params, 
+                         regressors= self.regressors,
+                         verbose = self.verbose,
+                         n_samples = self.n_samples,
+                         autocorrelation = self.autocorrelation,
+                         model_type = self.model_type)
+        return self
     
     def data_analysis(self):
         return self.analysis
